@@ -1187,8 +1187,8 @@ class Wavelet(Linop):
         self.wave_name = wave_name
         self.axes = axes
         self.level = level
-        oshape = wavelet.get_wavelet_shape(ishape, wave_name=wave_name,
-                                           axes=axes, level=level)
+        oshape, _ = wavelet.get_wavelet_shape(ishape, wave_name=wave_name,
+                                              axes=axes, level=level)
 
         super().__init__(oshape, ishape)
 
@@ -1224,16 +1224,17 @@ class InverseWavelet(Linop):
         self.wave_name = wave_name
         self.axes = axes
         self.level = level
-        ishape = wavelet.get_wavelet_shape(oshape, wave_name=wave_name,
-                                           axes=axes, level=level)
+        ishape, self.coeff_slices = wavelet.get_wavelet_shape(
+            oshape, wave_name=wave_name,
+            axes=axes, level=level)
         super().__init__(oshape, ishape)
 
     def _apply(self, input):
         device = backend.get_device(input)
         with device:
             return wavelet.iwt(
-                input, self.oshape, wave_name=self.wave_name,
-                axes=self.axes, level=self.level)
+                input, self.oshape, self.coeff_slices,
+                wave_name=self.wave_name, axes=self.axes, level=self.level)
 
     def _adjoint_linop(self):
         return Wavelet(self.oshape, axes=self.axes,
